package interpreter;

import java.io.*;

import environment.Environment;

public class LispInterpreterBuilderImpl implements LispInterpreterBuilder {

    private Environment environment;
    private String fileName;
    private boolean isInteractive;

    public LispInterpreterBuilderImpl() {
        this.environment = Environment.getInstance();
        this.fileName = "";
        this.isInteractive = true;
    }

    @Override
    public void setInput(InputStream inputStream) {
        this.environment.setInput(inputStream);
    }

    @Override
    public void setOutput(PrintStream outputStream) {
        this.environment.setOutput(outputStream);

    }

    @Override
    public void setErrorOutput(PrintStream errorOutputStream) {
        this.environment.setErrorOutput(errorOutputStream);
    }

    @Override
    public void setTerminate(Runnable terminationFunction) {
        this.environment.setTerminate(terminationFunction);
    }

    @Override
    public void useFile(String fileName) {
        this.fileName = fileName;
        this.isInteractive = false;
    }

    @Override
    public LispInterpreter build() {
        if (isInteractive)
            return new InteractiveLispInterpreter();
        else
            return new LispInterpreter(fileName);
    }

}
